@@ -29,6 +29,7 @@ def transport_for_sort(
     weights: jnp.ndarray,
     target_weights: jnp.ndarray,
     squashing_fun: Callable[[jnp.ndarray], jnp.ndarray] = None,
+    epsilon: float = 1e-2,
     **kwargs) -> jnp.ndarray:
   r"""Solves reg. OT, from inputs to a weighted family of increasing values.
 
@@ -53,21 +54,15 @@ def transport_for_sort(
 
   x = jnp.expand_dims(jnp.squeeze(inputs), axis=1)
   if squashing_fun is None:
-    squashing_fun = lambda z : jax.nn.sigmoid(
-        (z - jnp.mean(z)) / (jnp.std(z) + 1e-10))
+    squashing_fun = lambda z: jax.nn.sigmoid((z - jnp.mean(z)) /
+                                             (jnp.std(z) + 1e-10))
   x = squashing_fun(x)
   a = jnp.squeeze(weights)
   b = jnp.squeeze(target_weights)
   num_targets = b.shape[0]
   y = jnp.linspace(0.0, 1.0, num_targets)[:, jnp.newaxis]
 
-  # When runnning soft-sort, the entries are remapped into the segment [0,1].
-  # For that reason, it makes sense to have a default epsilon value adapted
-  # to that scale. If none is passed, we provide a default of 1e-2.
-  epsilon = kwargs.pop('epsilon', None)
-  scale = kwargs.pop('scale', None)
-  kwargs.update(epsilon=(1e-2 if epsilon is None else epsilon))
-  return transport.Transport(x, y, a=a, b=b, **kwargs)
+  return transport.Transport(x, y, a=a, b=b, epsilon=epsilon, **kwargs)
 
 
 def apply_on_axis(op, inputs, axis, *args, **kwargs):
